#!/usr/bin/env python3
import numpy as np
from pathlib import Path
import sys

parent = Path(sys.path[0])

p = parent.glob('**/coeff_abs.dat')
files = [x for x in p if x.is_file()]

dt = np.dtype([('index','i4'),('wavelength','f4'),('c0','f4'),('c1','f4'),('c2','f4'),('tr','f4'),('dp','f4')])
for coef_file in sorted(files):
    sensor = coef_file.parts[-2]
    if 'config' in sensor:
        continue

    coef = np.genfromtxt(coef_file, dtype=dt)#, skip_header=1)
    wvl = coef['wavelength']
    if np.any(np.isnan(wvl)):
        wvl = wvl[1:]
    sensor = coef_file.parts[-2]
    wvlstr = np.array2string(wvl, formatter={'float_kind':lambda x: "%.6f" % x},max_line_width=2500)
    print("{}: wavelengths= {}\n".format(sensor,wvlstr[1:-1]))
